Installation Guide
------------------
Now the Tricircle can be played with Devstack for all-in-one single pod and
multi-pod. You can build different Tricircle environments with Devstack
according to your needs. In the near future there will be a manual installation
guide in this installation guide that discussing how to install the Tricircle
step by step without DevStack for users who install OpenStack manually.





.. include:: ./single-pod-installation-devstack.rst
.. include:: ./multi-pod-installation-devstack.rst
.. include:: ./installation-manual.rst
.. include:: ./installation-cell.rst
.. include:: ./installation-lbaas.rst
.. include:: ./installation-lbaas_with_nova_cell_v2.rst
.. include:: ./installation-tricircle_work_with_container.rst